@@ -331,7 +331,7 @@ class XRedisAsync(Singleton):
             return self.conn
         return None
 
-    async def _get_connection(self, pipeline=False, transaction=False):
+    async def _get_connection(self, pipeline=False, transaction=True):
         conn = self.__get_connection()
         
         if conn is None:
